@@ -5,12 +5,12 @@
 # This method is used to define a user friendly name to represent a value,
 # a single cell or a range of cells in a workbook.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
 
-workbook = Workbook('defined_name.xlsx')
+workbook = xlsxwriter.Workbook('defined_name.xlsx')
 worksheet1 = workbook.add_worksheet()
 worksheet2 = workbook.add_worksheet()
 
