@@ -2,7 +2,7 @@
 #
 # A simple example of some of the features of the XlsxWriter Python module.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
 import xlsxwriter
 
@@ -15,7 +15,7 @@ worksheet = workbook.add_worksheet()
 worksheet.set_column('A:A', 20)
 
 # Add a bold format to use to highlight cells.
-bold = workbook.add_format({'bold': 1})
+bold = workbook.add_format({'bold': True})
 
 # Write some simple text.
 worksheet.write('A1', 'Hello')
