@@ -3,11 +3,11 @@
 # Example of using Python and the XlsxWriter module to create
 # worksheet panes.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('panes.xlsx')
+workbook = xlsxwriter.Workbook('panes.xlsx')
 
 worksheet1 = workbook.add_worksheet('Panes 1')
 worksheet2 = workbook.add_worksheet('Panes 2')
