@@ -2,7 +2,7 @@
 #
 # Chart - A class for writing the Excel XLSX Worksheet file.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
 import re
 from warnings import warn
@@ -10,6 +10,8 @@ from warnings import warn
 from . import xmlwriter
 from .utility import xl_color
 from .utility import xl_rowcol_to_cell
+from .utility import supported_datetime
+from .utility import datetime_to_excel_datetime
 
 
 class Chart(xmlwriter.XMLwriter):
@@ -88,6 +90,8 @@ class Chart(xmlwriter.XMLwriter):
         self.title_layout = None
         self.title_overlay = None
         self.title_none = False
+        self.date_category = False
+        self.date_1904 = False
 
         self._set_default_properties()
 
@@ -626,6 +630,21 @@ class Chart(xmlwriter.XMLwriter):
                 # Otherwise use the default value.
                 axis['position_axis'] = None
 
+        # Set the category axis as a date axis.
+        if options.get('date_axis'):
+            self.date_category = True
+
+        # Convert datetime args if required.
+        if axis.get('min') and supported_datetime(axis['min']):
+            axis['min'] = datetime_to_excel_datetime(axis['min'],
+                                                     self.date_1904)
+        if axis.get('max') and supported_datetime(axis['max']):
+            axis['max'] = datetime_to_excel_datetime(axis['max'],
+                                                     self.date_1904)
+        if axis.get('crossing') and supported_datetime(axis['crossing']):
+            axis['crossing'] = datetime_to_excel_datetime(axis['crossing'],
+                                                          self.date_1904)
+
         # Set the font properties if present.
         axis['num_font'] = self._convert_font_args(options.get('num_font'))
         axis['name_font'] = self._convert_font_args(options.get('name_font'))
@@ -686,7 +705,7 @@ class Chart(xmlwriter.XMLwriter):
                 cell = xl_rowcol_to_cell(name[1], name[2], True, True)
                 name_formula = name[0] + '!' + cell
                 name = ''
-            elif re.match(r'^=?[^!]+!', name):
+            elif re.match(r'^=?[^!]+!\$?[A-Z]+\$?[0-9]+', name):
                 # Name looks like a formula, use it to set name_formula.
                 name_formula = name
                 name = ''
@@ -1307,27 +1326,31 @@ class Chart(xmlwriter.XMLwriter):
         self._write_chart_type({'primary_axes': True})
         self._write_chart_type({'primary_axes': False})
 
-        # Write c:catAx and c:valAx elements for series using primary axes.
-        self._write_cat_axis({'x_axis': self.x_axis,
-                              'y_axis': self.y_axis,
-                              'axis_ids': self.axis_ids
-                              })
+        # Write the category and value elements for the primary axes.
+        args = {'x_axis': self.x_axis,
+                'y_axis': self.y_axis,
+                'axis_ids': self.axis_ids
+                }
 
-        self._write_val_axis({'x_axis': self.x_axis,
-                              'y_axis': self.y_axis,
-                              'axis_ids': self.axis_ids
-                              })
+        if self.date_category:
+            self._write_date_axis(args)
+        else:
+            self._write_cat_axis(args)
 
-        # Write c:valAx and c:catAx elements for series using secondary axes.
-        self._write_val_axis({'x_axis': self.x2_axis,
-                              'y_axis': self.y2_axis,
-                              'axis_ids': self.axis2_ids
-                              })
+        self._write_val_axis(args)
 
-        self._write_cat_axis({'x_axis': self.x2_axis,
-                              'y_axis': self.y2_axis,
-                              'axis_ids': self.axis2_ids
-                              })
+        # Write the category and value elements for the secondary axes.
+        args = {'x_axis': self.x2_axis,
+                'y_axis': self.y2_axis,
+                'axis_ids': self.axis2_ids
+                }
+
+        self._write_val_axis(args)
+
+        if self.date_category:
+            self._write_date_axis(args)
+        else:
+            self._write_cat_axis(args)
 
         # Write the c:dTable element.
         self._write_d_table()
