@@ -2,7 +2,7 @@
 #
 # Format - A class for writing the Excel XLSX Worksheet file.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
 
 # Package imports.
@@ -67,6 +67,7 @@ class Format(xmlwriter.XMLwriter):
         self.text_v_align = 0
         self.text_justlast = 0
         self.rotation = 0
+        self.center_across = 0
 
         self.fg_color = 0
         self.bg_color = 0
@@ -748,15 +749,6 @@ class Format(xmlwriter.XMLwriter):
     #
     ###########################################################################
 
-    def _assemble_xml_file(self):
-        # Assemble and write the XML file.
-
-        # Write the XML declaration.
-        self._xml_declaration()
-
-        # Close the file.
-        self._xml_close()
-
     def _get_align_properties(self):
         # Return properties for an Style xf <alignment> sub-element.
         changed = 0
